@@ -209,7 +209,15 @@ sub databases
 		{
 			@$con{ qw( host login passwd ) } = ( $SQL_SERVER, $DB_LOGIN, $DB_PASSWD );
 		}
-		$dbh = $self->connect( $con ) || return( undef() );
+		try
+		{
+			$dbh = $self->connect( $con ) || return( undef() );
+		}
+		catch( $e )
+		{
+			$self->message( 3, "An error occurred while trying to connect to get the list of available databases: $e" );
+			return;
+		}
 	}
 	else
 	{
