@@ -297,7 +297,15 @@ sub databases
 	## There should not be a live user and database just to check what databases there are.
 	if( !$self->{dbh} )
 	{
-		$dbh = $self->connect( $con ) || return( undef() );
+		try
+		{
+			$dbh = $self->connect( $con ) || return( undef() );
+		}
+		catch( $e )
+		{
+			$self->message( 3, "An error occurred while trying to connect to get the list of available databases: $e" );
+			return;
+		}
 	}
 	else
 	{
